@@ -1,4 +1,4 @@
-#   Copyright 2024 The PyMC Developers
+#   Copyright 2024 - present The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -13,7 +13,7 @@
 #   limitations under the License.
 from collections.abc import Callable
 from dataclasses import field
-from typing import Any
+from typing import Any, cast
 
 import numpy as np
 import numpy.random as nr
@@ -22,8 +22,11 @@ import scipy.linalg
 import scipy.special
 
 from pytensor import tensor as pt
+from pytensor.graph.basic import Variable
 from pytensor.graph.fg import MissingInputError
 from pytensor.tensor.random.basic import BernoulliRV, CategoricalRV
+from rich.progress import TextColumn
+from rich.table import Column
 
 import pymc as pm
 
@@ -325,6 +328,34 @@ class Metropolis(ArrayStepShared):
     def competence(var, has_grad):
         return Competence.COMPATIBLE
 
+    @staticmethod
+    def _progressbar_config(n_chains=1):
+        columns = [
+            TextColumn("{task.fields[tune]}", table_column=Column("Tuning", ratio=1)),
+            TextColumn("{task.fields[scaling]:0.2f}", table_column=Column("Scaling", ratio=1)),
+            TextColumn(
+                "{task.fields[accept_rate]:0.2f}", table_column=Column("Accept Rate", ratio=1)
+            ),
+        ]
+
+        stats = {
+            "tune": [True] * n_chains,
+            "scaling": [0] * n_chains,
+            "accept_rate": [0.0] * n_chains,
+        }
+
+        return columns, stats
+
+    @staticmethod
+    def _make_progressbar_update_functions():
+        def update_stats(step_stats):
+            return {
+                "accept_rate" if key == "accept" else key: step_stats[key]
+                for key in ("tune", "accept", "scaling")
+            }
+
+        return (update_stats,)
+
 
 def tune(scale, acc_rate):
     """
@@ -650,7 +681,6 @@ class BinaryGibbsMetropolis(ArrayStep):
 class CategoricalGibbsMetropolisState(StepMethodState):
     shuffle_dims: bool
     dimcats: list[tuple]
-    tune: bool
 
 
 class CategoricalGibbsMetropolis(ArrayStep):
@@ -733,10 +763,6 @@ class CategoricalGibbsMetropolis(ArrayStep):
         else:
             raise ValueError("Argument 'proposal' should either be 'uniform' or 'proportional'")
 
-        # Doesn't actually tune, but it's required to emit a sampler stat
-        # that indicates whether a draw was done in a tuning phase.
-        self.tune = True
-
         if compile_kwargs is None:
             compile_kwargs = {}
         super().__init__(vars, [model.compile_logp(**compile_kwargs)], blocked=blocked, rng=rng)
@@ -766,10 +792,8 @@ class CategoricalGibbsMetropolis(ArrayStep):
             if accepted:
                 logp_curr = logp_prop
 
-        stats = {
-            "tune": self.tune,
-        }
-        return q, [stats]
+        # This step doesn't have any tunable parameters
+        return q, [{"tune": False}]
 
     def astep_prop(self, apoint: RaveledVars, *args) -> tuple[RaveledVars, StatsType]:
         logp = args[0]
@@ -786,7 +810,8 @@ class CategoricalGibbsMetropolis(ArrayStep):
         for dim, k in dimcats:
             logp_curr = self.metropolis_proportional(q, logp, logp_curr, dim, k)
 
-        return q, []
+        # This step doesn't have any tunable parameters
+        return q, [{"tune": False}]
 
     def astep(self, apoint: RaveledVars, *args) -> tuple[RaveledVars, StatsType]:
         raise NotImplementedError()
@@ -1229,7 +1254,10 @@ def delta_logp(
     compile_kwargs: dict | None,
 ) -> pytensor.compile.Function:
     [logp0], inarray0 = join_nonshared_inputs(
-        point=point, outputs=[logp], inputs=vars, shared_inputs=shared
+        point=point,
+        outputs=[logp],
+        inputs=vars,
+        shared_inputs=cast(dict[Variable, Variable], shared),
     )
 
     tensor_type = inarray0.type
